==> ircii-2.8.45-pana.tar.gz: ircii-2.8/source/bot.c <==
#include "irc.h"
#include "server.h"
#include "edit.h"
#include "crypt.h"
#include "vars.h"
#include "ircaux.h"
#include "lastlog.h"
#include "window.h"
#include "screen.h"
#include "whois.h"
#include "hook.h"
#include "input.h"
#include "ignore.h"
#include "keys.h"
#include "names.h"
#include "alias.h"
#include "history.h"
#include "funny.h"
#include "ctcp.h"
#include "dcc.h"
#include "translat.h"
#include "output.h"
#include "exec.h"
#include "notify.h"
#include "numbers.h"
#include "status.h"
#include "list.h"
#include "bot.h"
#include "pluto.h"
#include "userlist.h"

UserList *Bot_list;
int bot_count = 0;

void bot _((char *, char *, char *));

void prepare_bothost(stuff, nick, args)
WhoisStuff *stuff;
char *nick, *args;
{
	UserList *new = NULL; 
	NickList *Nick;
	ChannelList *chan;
	char *p;
	char *uh;
	char *userhost = NULL;
	int remove_it = 0, aop = 0, prot = 0, i;

	if (*nick == '-') remove_it = 1;
        if (!stuff || !stuff->nick || !nick || !strcmp(stuff->user, "<UNKNOWN>") || my_stricmp(stuff->nick, nick))
        {
                say("No match for user %s", nick);
                return;
        }
	uh = stuff->user;
	if (*uh == '~' || *uh == '#')
		uh++;
	while (strlen(uh) > 9)
		uh++;
	p = next_arg(args, &args);
	remove_it = atoi(p);
	p = next_arg(args, &args);
	if (args && *args)
		aop = atoi(next_arg(args, &args));
	if (args && *args)
		prot = atoi(next_arg(args, &args));

	userhost = (char  *) new_malloc(strlen(uh) + strlen(stuff->host) + 5 );
	sprintf(userhost, "*%s@%s", uh, cluster(stuff->host));

	if (!remove_it) 
	{
		if ((new = nickinbot(nick, userhost)) == NULL) 
		{
			new = (UserList *) new_malloc(sizeof(UserList));
			memset(new, 0, sizeof(UserList));
			malloc_strcpy(&new->nick, nick);
			malloc_strcpy(&new->host, userhost);
			malloc_strcpy(&new->channels, p);
			new->aop = aop;
			new->prot = prot;
			bitchsay("Adding %s!%s to bot list", new->nick, userhost);
			bot_count++;
			add_to_list((List **)&Bot_list, (List *)new);
		} 
		else 
			bitchsay ("%s already in Bot list", nick);
		for (i = 0; i < number_of_servers; i++)
		{
			if (!(chan = server_list[i].chan_list))
				continue;
			Nick = (NickList *)find_in_list((List **)&chan->nicks, stuff->nick, 0);
			if (Nick)
				Nick->botlist = nickinbot(new->nick, userhost);
		}
	} 
	else 
	{
		if ((new = (UserList *) remove_from_list((List **) &Bot_list, nick)) != NULL) 
		{
			bitchsay("Removing %s from internal Bot list", nick);
			if (new->password) new_free(&new->password);
			if (new->host) new_free(&new->host);
			if (new->channels) new_free(&new->channels);
			if (new->nick) new_free(&new->nick);
			new_free((char **)&new);
			bot_count--;
			for (i = 0; i < number_of_servers; i++)
			{
				if (!(chan = server_list[i].chan_list))
					continue;
				Nick = (NickList *)find_in_list((List **)&chan->nicks, stuff->nick, 0);
				if (Nick)
					Nick->botlist = NULL;
			}
		}
	}
	new_free(&userhost);
}

void bot (char *command, char *args, char *subargs) {
int remove_it = 0;
int showit = 0;
int aop = 0, prot = 0;
UserList *new = NULL;
char *nick = NULL, *channels= NULL, *host = NULL, *tmp = NULL;
char *p, *q;

	if (command && *command && (my_stricmp(command, "BOTLIST")==0))
		showit = 1;

	if (*args && showit == 0) {
		if (command && *command && (my_stricmp(command, "UNBOT") ==0))
			remove_it = 1;
		p = next_arg(args, &args);
		malloc_strcpy(&tmp, p);
		p = next_arg(args, &args);
		if (!p || !*p) 
			p = "*";
		malloc_strcpy(&channels, p);
		if (args && *args)
			aop = atoi(next_arg(args, &args));
		if (args && *args)
			prot = atoi(next_arg(args, &args));

		if (strchr(tmp, '!')) {
			if (strchr(tmp, '@')) {
				q = tmp;
				nick = q;
				host = strchr(q,'!');
				*host++ = '\0';
				if (remove_it) {
					if ((new = (UserList *) remove_from_list((List **) &Bot_list, nick)) != NULL) {
						new_free(&new->password);
						new_free(&new->host);
						new_free(&new->channels);
						new_free(&new->nick);
						new_free((char **)&new);
						new_free(&channels);
						new_free((char **)&tmp);
						bot_count--;
					}
				} else {
					if ((new = nickinbot(nick, host)) == NULL) {
						new = (UserList *) new_malloc(sizeof(UserList));
						memset(new, 0, sizeof(UserList));
						if (host) malloc_strcpy(&new->host, host);
						if (nick) malloc_strcpy(&new->nick, nick);
						if (channels) malloc_strcpy(&new->channels, channels);
						new_free(&tmp);
						new->aop = aop;
						new->prot = prot;
						add_to_list((List **)&Bot_list, (List *)new);
						bot_count++;
					}
				}
			}
		}  else
			add_to_userhost_queue(tmp, prepare_bothost, "%d %s %d %d", remove_it, channels? channels:"*", aop, prot);
				
	} 
	else if (showit) 
	{
		int first_time = 0;
		new = Bot_list;
		if (!new) {
			bitchsay("No Botz on internal Bot list");
			return;
		}
		while (new) {
			if (do_hook(BOTLIST_LIST, "%d %d %s %s %s", new->aop, new->prot, new->nick, new->channels, new->host?new->host:"*"))
			{
				if (!first_time)
					put_it("Aop Prot Bot         Channel    Hostname");
				put_it("%2d %2d %-11s %-10s %s", new->aop, new->prot, new->nick, new->channels, new->host?new->host:"*");
			}
			first_time++;
			new = new->next;
		}
		bitchsay("End of Bot list %d count", first_time);
	} else
		bitchsay("%s <nick> <channel>", (command && *command) ? command : "BOT");
}

void save_bot(FILE *fp)
{
UserList *tmp = Bot_list;
int count = 0;
	if (!tmp)
		return;
	fprintf(fp, "# %s Bot list\n", version);
	while(tmp) {
		fprintf(fp, "BOT %s!%s %s %d %d\n", tmp->nick, tmp->host, tmp->channels, tmp->aop, tmp->prot);
		tmp = tmp->next;
		count++;
	}
	if (do_hook(SAVEFILE_LIST, "BotList %d", count))
		bitchsay("Saved %d BotList entries", count);
}

==> ircii-2.8.51-pana.tar.gz: ircii-2.8/source/bot.c <==
#include "irc.h"
#include "server.h"
#include "edit.h"
#include "crypt.h"
#include "vars.h"
#include "ircaux.h"
#include "lastlog.h"
#include "window.h"
#include "screen.h"
#include "whois.h"
#include "hook.h"
#include "input.h"
#include "ignore.h"
#include "keys.h"
#include "names.h"
#include "alias.h"
#include "history.h"
#include "funny.h"
#include "ctcp.h"
#include "dcc.h"
#include "translat.h"
#include "output.h"
#include "exec.h"
#include "notify.h"
#include "numbers.h"
#include "status.h"
#include "list.h"
#include "bot.h"
#include "pluto.h"
#include "userlist.h"

UserList *Bot_list;
int bot_count = 0;

void bot _((char *, char *, char *));

void sync_botlist(UserList *new, int type)
{
ChannelList *chan;
NickList *nick;
int i;
	for (i = 0; i < number_of_servers; i++)
	{
		for (chan = server_list[i].chan_list; chan; chan = chan->next)
		{
			for (nick = chan->nicks; nick; nick = nick->next)
			{
				if (wild_match(new->nick, nick->nick) && wild_match(new->host, nick->host))
					if (type) 
						nick->botlist = new;
					else 
						nick->botlist = NULL;	
			}
		}
	}
}

void prepare_bothost(stuff, nick, args)
WhoisStuff *stuff;
char *nick, *args;
{
	UserList *new = NULL; 
	char *p;
	char *uh;
	char *userhost = NULL;
	int remove_it = 0, aop = 0, prot = 0;

	if (*nick == '-') remove_it = 1;
        if (!stuff || !stuff->nick || !nick || !strcmp(stuff->user, "<UNKNOWN>") || my_stricmp(stuff->nick, nick))
        {
                say("No match for user %s", nick);
                return;
        }
	uh = stuff->user;
	if (*uh == '~' || *uh == '#')
		uh++;
	while (strlen(uh) > 9)
		uh++;
	p = next_arg(args, &args);
	remove_it = atoi(p);
	p = next_arg(args, &args);
	if (args && *args)
		aop = atoi(next_arg(args, &args));
	if (args && *args)
		prot = atoi(next_arg(args, &args));

	userhost = (char  *) new_malloc(strlen(uh) + strlen(stuff->host) + 5 );
	sprintf(userhost, "*%s@%s", uh, cluster(stuff->host));

	if (!remove_it) 
	{
		if ((new = nickinbot(nick, userhost)) == NULL) 
		{
			new = (UserList *) new_malloc(sizeof(UserList));
			memset(new, 0, sizeof(UserList));
			malloc_strcpy(&new->nick, nick);
			malloc_strcpy(&new->host, userhost);
			malloc_strcpy(&new->channels, p);
			new->aop = aop;
			new->prot = prot;
			bitchsay("Adding %s!%s to bot list", new->nick, userhost);
			bot_count++;
			add_to_list((List **)&Bot_list, (List *)new);
			sync_botlist(new, 1);
		} 
		else 
			bitchsay ("%s already in Bot list", nick);
	} 
	else 
	{
		if ((new = (UserList *) remove_from_list((List **) &Bot_list, nick)) != NULL) 
		{
			bitchsay("Removing %s from internal Bot list", nick);
			sync_botlist(new, 0);
			if (new->password) new_free(&new->password);
			if (new->host) new_free(&new->host);
			if (new->channels) new_free(&new->channels);
			if (new->nick) new_free(&new->nick);
			new_free((char **)&new);
			bot_count--;
		}
	}
	new_free(&userhost);
}


void bot (char *command, char *args, char *subargs) {
int remove_it = 0;
int showit = 0;
int aop = 0, prot = 0;
UserList *new = NULL;
char *nick = NULL, *channels= NULL, *host = NULL, *tmp = NULL;
char *p, *q;

	if (command && *command && (my_stricmp(command, "BOTLIST")==0))
		showit = 1;

	if (*args && showit == 0) {
		if (command && *command && (my_stricmp(command, "UNBOT") ==0))
			remove_it = 1;
		p = next_arg(args, &args);
		malloc_strcpy(&tmp, p);
		p = next_arg(args, &args);
		if (!p || !*p) 
			p = "*";
		malloc_strcpy(&channels, p);
		if (args && *args)
			aop = atoi(next_arg(args, &args));
		if (args && *args)
			prot = atoi(next_arg(args, &args));

		if (strchr(tmp, '!')) {
			if (strchr(tmp, '@')) {
				q = tmp;
				nick = q;
				host = strchr(q,'!');
				*host++ = '\0';
				if (remove_it) {
					if ((new = (UserList *) remove_from_list((List **) &Bot_list, nick)) != NULL) {
						sync_botlist(new, 0);
						new_free(&new->password);
						new_free(&new->host);
						new_free(&new->channels);
						new_free(&new->nick);
						new_free((char **)&new);
						new_free(&channels);
						new_free((char **)&tmp);
						bot_count--;
					}
				} else {
					if ((new = nickinbot(nick, host)) == NULL) {
						new = (UserList *) new_malloc(sizeof(UserList));
						memset(new, 0, sizeof(UserList));
						if (host) malloc_strcpy(&new->host, host);
						if (nick) malloc_strcpy(&new->nick, nick);
						if (channels) malloc_strcpy(&new->channels, channels);
						new_free(&tmp);
						new->aop = aop;
						new->prot = prot;
						add_to_list((List **)&Bot_list, (List *)new);
						bot_count++;
						sync_botlist(new, 1);
					}
				}
			}
		}  else
			add_to_userhost_queue(tmp, prepare_bothost, "%d %s %d %d", remove_it, channels? channels:"*", aop, prot);
				
	} 
	else if (showit) 
	{
		int first_time = 0;
		new = Bot_list;
		if (!new) {
			bitchsay("No Botz on internal Bot list");
			return;
		}
		while (new) {
			if (do_hook(BOTLIST_LIST, "%d %d %s %s %s", new->aop, new->prot, new->nick, new->channels, new->host?new->host:"*"))
			{
				if (!first_time)
					put_it("Aop Prot Bot         Channel    Hostname");
				put_it("%2d %2d %-11s %-10s %s", new->aop, new->prot, new->nick, new->channels, new->host?new->host:"*");
			}
			first_time++;
			new = new->next;
		}
		bitchsay("End of Bot list %d count", first_time);
	} else
		bitchsay("%s <nick> <channel>", (command && *command) ? command : "BOT");
}

void save_bot(FILE *fp)
{
UserList *tmp = Bot_list;
int count = 0;
	if (!tmp)
		return;
	fprintf(fp, "# %s Bot list\n", version);
	while(tmp) {
		fprintf(fp, "BOT %s!%s %s %d %d\n", tmp->nick, tmp->host, tmp->channels, tmp->aop, tmp->prot);
		tmp = tmp->next;
		count++;
	}
	if (do_hook(SAVEFILE_LIST, "BotList %d", count))
		bitchsay("Saved %d BotList entries", count);
}
